import { ICatalog } from '../catalog';
import { CatalogComponents } from '../types';
/**
 * `useCatalog` (react-hook) returns the `catalog` provided to `CatalogProvider`
 *
 * @example
 * ```
 * const catalog = useCatalog()
 * const Button = catalog.getComponent("button")
 * ```
 */
export declare const useCatalog: <T extends Record<string, any> = CatalogComponents>() => ICatalog<T>;
/**
 * ATTENTION: only use _internally_, do not export for users of this lib!
 *
 * We do not use `CatalogComponents` here, because this hook is used when the
 * types of the `ICatalog` components are not relevant.
 *
 * NOTE: internally we do not care about the type of T, that is why it can have
 * any object shape
 */
export declare const useUNSAFECatalog: <T extends Record<string, any>>() => ICatalog<T>;
//# sourceMappingURL=use-catalog.d.ts.map